@@ -215,7 +215,7 @@ namespace dbmm
                 break;
             }
 
-            OSL_ENSURE( false, "lcl_getScriptsSubStorageName: illegal type!" );
+            OSL_FAIL( "lcl_getScriptsSubStorageName: illegal type!" );
             static ::rtl::OUString s_sEmpty;
             return s_sEmpty;
         }
@@ -250,7 +250,7 @@ namespace dbmm
                     return true;
                 }
             }
-            OSL_ENSURE( false, "lcl_getScriptTypeFromLanguage: unknown language!" );
+            OSL_FAIL( "lcl_getScriptTypeFromLanguage: unknown language!" );
             return false;
         }
 
@@ -333,7 +333,7 @@ namespace dbmm
                 bool bCausedByNewStyleReport =
                         ( _rDocument.eType == eReport )
                     &&  ( aError.isExtractableTo( ::cppu::UnoType< WrongFormatException >::get() ) )
-                    &&  ( lcl_getMimeType_nothrow( _rDocument.xCommandProcessor ).equalsAscii( "application/vnd.sun.xml.report" ) );
+                    &&  ( lcl_getMimeType_nothrow( _rDocument.xCommandProcessor ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "application/vnd.sun.xml.report" ) ) );
 
                 if ( bCausedByNewStyleReport )
                 {
@@ -1020,7 +1020,7 @@ namespace dbmm
     {
         if  ( m_aSubDocs.empty() )
         {
-            OSL_ENSURE( false, "MigrationEngine_Impl::migrateAll: no forms/reports found!" );
+            OSL_FAIL( "MigrationEngine_Impl::migrateAll: no forms/reports found!" );
             // The whole migration wizard is not expected to be called when there are no forms/reports
             // with macros, not to mention when there are no forms/reports at all.
             return false;
@@ -1163,7 +1163,7 @@ namespace dbmm
         aProgressMixer.registerPhase( PHASE_PYTHON, 1 );
         aProgressMixer.registerPhase( PHASE_JAVA, 1 );
         aProgressMixer.registerPhase( PHASE_BASIC, 5 );
-            // more weight than then others, assuming that usually, there are much more Basic macros than any other scripts
+            // more weight than the others, assuming that usually, there are many more Basic macros than any other scripts
         aProgressMixer.registerPhase( PHASE_DIALOGS, 1 );
 
         bool bSuccess = impl_checkScriptStorageStructure_nothrow( aSubDocument );
@@ -1223,7 +1223,7 @@ namespace dbmm
             const ::rtl::OUString& _rSourceLibName, const Reference< XNameAccess >& _rxTargetContainer )
         {
             // The new library name is composed from the prefix, the base name, and the old library name.
-            const ::rtl::OUString sPrefix( ::rtl::OUString::createFromAscii( _rDocument.eType == eForm ? "Form_" : "Report_" ) );
+            const ::rtl::OUString sPrefix = (_rDocument.eType == eForm)?rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Form_")): rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Report_"));
 
             ::rtl::OUString sBaseName( _rDocument.sHierarchicalName.copy(
                 _rDocument.sHierarchicalName.lastIndexOf( '/' ) + 1 ) );
@@ -1232,8 +1232,8 @@ namespace dbmm
             // The bug requesting to change this is #i95409#.
             // Unfortunately, the storage implementation does not complain if you use invalid characters/names, but instead
             // it silently accepts them, and produces garbage in the file (#i95408).
-            // So, until especially the former is fixed, we need to strip the name from all invalid characters.
-            // #i95865# / 2008-11-06 / frank.schoenheit@sun.com
+            // So, until especially the former is fixed, we need to strip all invalid characters from the name.
+            // #i95865#
 
             // The general idea is to replace invalid characters with '_'. However, since "valid" essentially means
             // ASCII only, this implies that for a lot of languages, we would simply replace everything with '_',
@@ -1639,7 +1639,7 @@ namespace dbmm
                 ||  !_rScriptType.getLength()
                 )
             {
-                OSL_ENSURE( false,
+                OSL_FAIL(
                     "MigrationEngine_Impl::impl_adjustScriptLibrary_nothrow: no or unknown script type!" );
                 m_rLogger.logRecoverable( MigrationError(
                     ERR_UNKNOWN_SCRIPT_TYPE,
@@ -1657,7 +1657,7 @@ namespace dbmm
             ScriptType eScriptType = eBasic;
             if ( !lcl_getScriptTypeFromLanguage( sScriptLanguage, eScriptType ) )
             {
-                OSL_ENSURE( false,
+                OSL_FAIL(
                     "MigrationEngine_Impl::impl_adjustScriptLibrary_nothrow: unknown script language!" );
                 m_rLogger.logRecoverable( MigrationError(
                     ERR_UNKNOWN_SCRIPT_LANGUAGE,
@@ -1668,7 +1668,7 @@ namespace dbmm
 
             ::rtl::OUString sLocation = xUri->getParameter(
                 ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "location" ) ) );
-            if ( !sLocation.equalsAscii( "document" ) )
+            if ( !sLocation.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "document" ) ) )
             {
                 // only document libraries must be migrated, of course
                 return false;
@@ -1678,7 +1678,7 @@ namespace dbmm
             sal_Int32 nLibModuleSeparator = sScriptName.indexOf( '.' );
             if ( nLibModuleSeparator < 0 )
             {
-                OSL_ENSURE( false,
+                OSL_FAIL(
                     "MigrationEngine_Impl::impl_adjustScriptLibrary_nothrow: invalid/unknown location format!" );
                 m_rLogger.logRecoverable( MigrationError(
                     ERR_UNKNOWN_SCRIPT_NAME_FORMAT,
