@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -113,20 +114,20 @@ public:
         long nReportSize = GetItemSize( REPORT_ID );
         long nTaskPaneSize = GetItemSize( TASKPANE_ID );
 
-        BOOL		bMod = FALSE;
+        sal_Bool		bMod = sal_False;
         if( nReportSize < nReportMinSplitSize )
         {
             nReportSize = nReportMinSplitSize;
             nTaskPaneSize = 99 - nReportMinSplitSize;
 
-            bMod = TRUE;
+            bMod = sal_True;
         }
         else if( nTaskPaneSize < nTaskPaneMinSplitSize )
         {
             nTaskPaneSize = nTaskPaneMinSplitSize;
             nReportSize = 99 - nTaskPaneMinSplitSize;
 
-            bMod = TRUE;
+            bMod = sal_True;
         }
 
         if( bMod )
@@ -155,12 +156,12 @@ ODesignView::ODesignView(   Window* pParent,
     ,m_eMode( RPTUI_SELECT )
     ,m_nCurrentPosition(USHRT_MAX)
     ,m_eActObj( OBJ_NONE )
-    ,m_bFirstDraw(FALSE)
+    ,m_bFirstDraw(sal_False)
     ,m_aGridSizeCoarse( 1000, 1000 )	// #i93595# 100TH_MM changed to grid using coarse 1 cm grid
     ,m_aGridSizeFine( 250, 250 )        // and a 0,25 cm subdivision for better visualisation
-    ,m_bGridVisible(TRUE)
-    ,m_bGridSnap(TRUE)
-    ,m_bDeleted( FALSE )
+    ,m_bGridVisible(sal_True)
+    ,m_bGridSnap(sal_True)
+    ,m_bDeleted( sal_False )
 {
     DBG_CTOR( rpt_ODesignView,NULL);
     SetHelpId(UID_RPT_RPT_APP_VIEW);
@@ -170,14 +171,11 @@ ODesignView::ODesignView(   Window* pParent,
 
     // now create the task pane on the right side :-)
     m_pTaskPane = new OTaskWindow(this);
-    //m_pTaskPane->Show();
 
     m_aSplitWin.InsertItem( COLSET_ID,100,SPLITWINDOW_APPEND, 0, SWIB_PERCENTSIZE | SWIB_COLSET );
-    m_aSplitWin.InsertItem( REPORT_ID, &m_aScrollWindow, 100/*m_aScrollWindow.getMaxMarkerWidth(sal_False)*/, SPLITWINDOW_APPEND, COLSET_ID, SWIB_PERCENTSIZE  /*SWIB_COLSET*/);
-    //m_aSplitWin.InsertItem( TASKPANE_ID, m_pTaskPane, 50, SPLITWINDOW_APPEND, 0, SWIB_PERCENTSIZE );
+    m_aSplitWin.InsertItem( REPORT_ID, &m_aScrollWindow, 100, SPLITWINDOW_APPEND, COLSET_ID, SWIB_PERCENTSIZE);
 
     // Splitter einrichten
-    //m_aSplitter.SetSplitHdl(LINK(this, ODesignView,SplitHdl));
     m_aSplitWin.SetSplitHdl(LINK(this, ODesignView,SplitHdl));
     m_aSplitWin.ShowAutoHideButton();
     m_aSplitWin.SetAlign(WINDOWALIGN_LEFT);
@@ -191,7 +189,7 @@ ODesignView::ODesignView(   Window* pParent,
 ODesignView::~ODesignView()
 {
     DBG_DTOR( rpt_ODesignView,NULL);
-    m_bDeleted = TRUE;
+    m_bDeleted = sal_True;
     Hide();
     m_aScrollWindow.Hide();
     m_aMarkTimer.Stop();
@@ -203,7 +201,7 @@ ODesignView::~ODesignView()
     }
     if ( m_pAddField )
     {
-        SvtViewOptions aDlgOpt( E_WINDOW, String::CreateFromInt32( UID_RPT_RPT_APP_VIEW ) );
+        SvtViewOptions aDlgOpt( E_WINDOW, String::CreateFromAscii( UID_RPT_RPT_APP_VIEW ) );
         aDlgOpt.SetWindowState( ::rtl::OUString::createFromAscii( m_pAddField->GetWindowState(WINDOWSTATE_MASK_ALL).GetBuffer() ) );
         notifySystemWindow(this,m_pAddField,::comphelper::mem_fun(&TaskPaneList::RemoveWindow));
         ::std::auto_ptr<Window> aTemp2(m_pAddField);
@@ -248,7 +246,12 @@ long ODesignView::PreNotify( NotifyEvent& rNEvt )
     switch(rNEvt.GetType())
     {
         case EVENT_KEYINPUT:
-            //if ( nRet != 1L )
+            if ( (m_pPropWin && m_pPropWin->HasChildPathFocus()) )
+                return 0L;
+            if ( (m_pAddField && m_pAddField->HasChildPathFocus()) )
+                return 0L;
+            if ( (m_pReportExplorer && m_pReportExplorer->HasChildPathFocus()) )
+                return 0L;
             {
                 const KeyEvent* pKeyEvent = rNEvt.GetKeyEvent();
                 if ( handleKeyEvent(*pKeyEvent) )
@@ -290,7 +293,7 @@ void ODesignView::resizeDocumentView(Rectangle& _rPlayground)
                 nSplitPos = static_cast<sal_Int32>(_rPlayground.Right() - nMinWidth);
                 getController().setSplitPos(nSplitPos);
             }
-        } // if ( 0 != _rPlaygroundSize.Width() )
+        }
 
         Size aReportWindowSize(aPlaygroundSize);
         if ( m_aSplitWin.IsItemValid(TASKPANE_ID) )
@@ -358,7 +361,7 @@ void ODesignView::SetMode( DlgEdMode _eNewMode )
     m_aScrollWindow.SetMode(_eNewMode);
 }
 //----------------------------------------------------------------------------
-void ODesignView::SetInsertObj( USHORT eObj,const ::rtl::OUString& _sShapeType )
+void ODesignView::SetInsertObj( sal_uInt16 eObj,const ::rtl::OUString& _sShapeType )
 {
     m_eActObj = eObj;
     m_aScrollWindow.SetInsertObj( eObj,_sShapeType );
@@ -370,7 +373,7 @@ rtl::OUString ODesignView::GetInsertObjString() const
 }
 //----------------------------------------------------------------------------
 
-USHORT ODesignView::GetInsertObj() const
+sal_uInt16 ODesignView::GetInsertObj() const
 {
     return m_eActObj;
 }
@@ -401,13 +404,13 @@ void ODesignView::Delete()
     m_aScrollWindow.Delete();
 }
 //----------------------------------------------------------------------------
-BOOL ODesignView::HasSelection() const
+sal_Bool ODesignView::HasSelection() const
 {
     return m_aScrollWindow.HasSelection();
 }
 //----------------------------------------------------------------------------
 
-BOOL ODesignView::IsPasteAllowed() const
+sal_Bool ODesignView::IsPasteAllowed() const
 {
     return m_aScrollWindow.IsPasteAllowed();
 }
@@ -435,7 +438,7 @@ void ODesignView::toggleGrid(sal_Bool _bGridVisible)
      m_aScrollWindow.toggleGrid(_bGridVisible);
 }
 //----------------------------------------------------------------------------
-USHORT ODesignView::getSectionCount() const
+sal_uInt16 ODesignView::getSectionCount() const
 {
     return m_aScrollWindow.getSectionCount();
 }
@@ -445,12 +448,12 @@ void ODesignView::showRuler(sal_Bool _bShow)
      m_aScrollWindow.showRuler(_bShow);
 }
 //----------------------------------------------------------------------------
-void ODesignView::removeSection(USHORT _nPosition)
+void ODesignView::removeSection(sal_uInt16 _nPosition)
 {
      m_aScrollWindow.removeSection(_nPosition);
 }
 //----------------------------------------------------------------------------
-void ODesignView::addSection(const uno::Reference< report::XSection >& _xSection,const ::rtl::OUString& _sColorEntry,USHORT _nPosition)
+void ODesignView::addSection(const uno::Reference< report::XSection >& _xSection,const ::rtl::OUString& _sColorEntry,sal_uInt16 _nPosition)
 {
      m_aScrollWindow.addSection(_xSection,_sColorEntry,_nPosition);
 }
@@ -469,11 +472,7 @@ void ODesignView::GetFocus()
 // -----------------------------------------------------------------------------
 void ODesignView::ImplInitSettings()
 {
-//#if OSL_DEBUG_LEVEL > 0
-//    SetBackground( Wallpaper( COL_RED ));
-//#else
     SetBackground( Wallpaper( Application::GetSettings().GetStyleSettings().GetFaceColor() ));
-//#endif
     SetFillColor( Application::GetSettings().GetStyleSettings().GetFaceColor() );
     SetTextFillColor( Application::GetSettings().GetStyleSettings().GetFaceColor() );
 }
@@ -529,12 +528,10 @@ void ODesignView::togglePropertyBrowser(sal_Bool _bToogleOn)
         m_pTaskPane->Invalidate();
 
         if ( bWillBeVisible )
-            m_aSplitWin.InsertItem( TASKPANE_ID, m_pTaskPane,START_SIZE_TASKPANE, SPLITWINDOW_APPEND, COLSET_ID, SWIB_PERCENTSIZE/*|SWIB_COLSET */);
+            m_aSplitWin.InsertItem( TASKPANE_ID, m_pTaskPane,START_SIZE_TASKPANE, SPLITWINDOW_APPEND, COLSET_ID, SWIB_PERCENTSIZE);
         else
             m_aSplitWin.RemoveItem(TASKPANE_ID);
 
-        // TRY
-        // Invalidate(/*INVALIDATE_NOCHILDREN|INVALIDATE_NOERASE*/);
         if ( bWillBeVisible )
             m_aMarkTimer.Start();
     }
@@ -552,7 +549,7 @@ void ODesignView::showProperties(const uno::Reference< uno::XInterface>& _xRepor
     }
 }
 //-----------------------------------------------------------------------------
-BOOL ODesignView::isReportExplorerVisible() const
+sal_Bool ODesignView::isReportExplorerVisible() const
 {
     return m_pReportExplorer && m_pReportExplorer->IsVisible();
 }
@@ -573,7 +570,7 @@ void ODesignView::toggleReportExplorer()
         m_pReportExplorer->Show(!m_pReportExplorer->IsVisible());
 }
 //-----------------------------------------------------------------------------
-BOOL ODesignView::isAddFieldVisible() const
+sal_Bool ODesignView::isAddFieldVisible() const
 {
     return m_pAddField && m_pAddField->IsVisible();
 }
@@ -600,7 +597,7 @@ void ODesignView::toggleAddField()
         uno::Reference < beans::XPropertySet > xSet(rReportController.getRowSet(),uno::UNO_QUERY);
         m_pAddField = new OAddFieldWindow(this,xSet);
         m_pAddField->SetCreateHdl(LINK( &rReportController, OReportController, OnCreateHdl ) );
-        SvtViewOptions aDlgOpt( E_WINDOW, String::CreateFromInt32( UID_RPT_RPT_APP_VIEW ) );
+        SvtViewOptions aDlgOpt( E_WINDOW, String::CreateFromAscii( UID_RPT_RPT_APP_VIEW ) );
         if ( aDlgOpt.Exists() )
             m_pAddField->SetWindowState( ByteString( aDlgOpt.GetWindowState().getStr(), RTL_TEXTENCODING_ASCII_US ) );
         m_pAddField->Update();
@@ -618,12 +615,6 @@ uno::Reference< report::XSection > ODesignView::getCurrentSection() const
     if ( m_pCurrentView )
         xSection = m_pCurrentView->getReportSection()->getSection();
 
-    // why do we need the code below?
-    //else
- //   {
- //       OReportController& rReportController = getController();
- //       xSection = rReportController.getReportDefinition()->getDetail();
- //   }
     return xSection;
 }
 // -----------------------------------------------------------------------------
@@ -677,14 +668,6 @@ void ODesignView::alignMarkedObjects(sal_Int32 _nControlModification,bool _bAlig
 {
     m_aScrollWindow.alignMarkedObjects(_nControlModification, _bAlignAtSection,bBoundRects);
 }
-#if 0
-// -----------------------------------------------------------------------------
-sal_Bool ODesignView::isAlignPossible() const
-{
-    ::boost::shared_ptr<OSectionWindow> pMarkedSection = getMarkedSection();
-    return pMarkedSection.get() && pMarkedSection->getReportSection().getSectionView().IsAlignPossible();
-}
-#endif
 //------------------------------------------------------------------------------
 sal_Bool ODesignView::handleKeyEvent(const KeyEvent& _rEvent)
 {
@@ -752,13 +735,13 @@ void ODesignView::fillControlModelSelection(::std::vector< uno::Reference< uno::
     m_aScrollWindow.fillControlModelSelection(_rSelection);
 }
 // -----------------------------------------------------------------------------
-void ODesignView::setGridSnap(BOOL bOn)
+void ODesignView::setGridSnap(sal_Bool bOn)
 {
     m_aScrollWindow.setGridSnap(bOn);
 
 }
 // -----------------------------------------------------------------------------
-void ODesignView::setDragStripes(BOOL bOn)
+void ODesignView::setDragStripes(sal_Bool bOn)
 {
     m_aScrollWindow.setDragStripes(bOn);
 }
@@ -785,3 +768,5 @@ sal_uInt16 ODesignView::getZoomFactor(SvxZoomType _eType) const
 //============================================================================
 } // rptui
 //============================================================================
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
